@@ -369,9 +369,10 @@ build <- function(Package, VersionOnRepos, verbose, quiet, out) {
         intern = internal, ignore.stdout = quiet, ignore.stderr = quiet
       )
     })
-    if (any(unlist(out1) == 1L)) {
-      browserDeveloper("Error 456; contact developer")
-    }
+    # if (any(unlist(out1) == 1L)) {
+    #   browser()
+    #   browserDeveloper("Error 456; contact developer")
+    # }
     messageVerbose("  ... Built!",
       verbose = verbose, verboseLevel = 1
     )
@@ -482,10 +483,18 @@ doInstalls <- function(pkgDT, repos, purge, tmpdir, libPaths, verbose, install.p
         ),
         installAll
       )
-    pkgInstall <- rbindlistRecursive(toInstallList)
-    # afterInstallAll <- by(pkgInstall, list(pkgInstall[["installSafeGroups"]]),
-    #    installAll, repos = repos, purge = purge, install.packagesArgs, numPackages,
-    #    numGroups = maxGroup, startTime, verbose, type = type)
+    pkgInstallTmp <- rbindlistRecursive(toInstallList)
+    needRebuild <- startsWith(basename(pkgInstall$localFile), "NeedRebuild")
+    if (any(needRebuild)) {
+      pkgInstall <- needRebuildAndInstall(needRebuild = needRebuild, pkgInstall = pkgInstall,
+                                          libPaths = libPaths, verbose = verbose,
+                                          install.packagesArgs = install.packagesArgs,
+                                          repos = repos, purge = purge, startTime = startTime, type = type,
+                                          pkgInstallTmp = pkgInstallTmp)
+    } else {
+      pkgInstall <- pkgInstallTmp
+    }
+
     addOK <- if (!is.null(pkgInstall[["installResult"]])) {
       which(is.na(pkgInstall[["installResult"]]))
     } else {
@@ -785,7 +794,7 @@ doLoads <- function(require, pkgDT) {
   if (any(pkgDT$require %in% TRUE)) {
     setorderv(pkgDT, "loadOrder", na.last = TRUE)
     # rstudio intercepts `require` and doesn't work internally
-    out[[1]] <- mapply(x = pkgDT$Package[pkgDT$require %in% TRUE], function(x) {
+    out[[1]] <- mapply(x = unique(pkgDT$Package[pkgDT$require %in% TRUE]), function(x) {
       base::require(x, character.only = TRUE)
     }, USE.NAMES = TRUE)
   }
@@ -861,7 +870,30 @@ doDownloads <- function(pkgInstall, repos, purge, verbose, install.packagesArgs,
     verbose = verbose,
     type = type
   )
-  pkgInstall <- checkAvailableVersions(pkgInstall, repos, purge, libPaths, verbose = verbose, type = type)
+  # When GITHUB_PAT rate limit is hit, the error message in Require is useless;
+  #   use `remotes`
+  pkgInstall <-
+    withCallingHandlers(checkAvailableVersions(pkgInstall, repos, purge, libPaths,
+                                               verbose = verbose, type = type),
+                        error = function(e) {
+                          e$message <- gsub(paste0("(https://).*@"), "\\1", e$message)
+                          if (requireNamespace("remotes")) {
+                            # THIS WILL TRY `remotes` TO GET THE CORRECT REASON FOR THE ERROR -- but will still error
+                            pkgInstallJustGitHub <- pkgInstall[pkgInstall$repoLocation %in% "GitHub"]
+                            lapply(seq(NROW(pkgInstallJustGitHub)),
+                                   function(ind) {
+                                     pijg <- pkgInstallJustGitHub[ind]
+                                     thisOne <- any(grepl(paste(pijg$Account, pijg$Repo, sep = ".+"), e))
+                                     if (isTRUE(thisOne))
+                                       remotes::install_github(pijg$packageFullName)
+                                   })
+
+                          } else {
+                            stop(e, "\nDoes the url exist? ",
+                                 "Are you not using a GITHUB_PAT? Do you have an old GITHUB_PAT?\n",
+                                 "For better error handling, install.packages('remotes')")
+                          }
+                        })
   pkgInstall <- identifyLocalFiles(pkgInstall, repos, purge, libPaths, verbose = verbose)
 
   pkgInstallList <- split(pkgInstall, by = "haveLocal")
@@ -1025,14 +1057,19 @@ downloadGitHub <- function(pkgNoLocal, libPaths, verbose, install.packagesArgs,
         }
         pkgGHtoDL[!SHAonGH %in% FALSE, localFile := {
         #  toDL <- .SD[!SHAonGH %in% FALSE]
-          gitRepo <- paste0(Account, "/", Repo, "@", Branch)
-          names(gitRepo) <- Package
-          out <- downloadRepo(gitRepo, subFolder = GitSubFolder,
-                              overwrite = TRUE, destDir = ".", verbose = verbose)
-          out1 <- try(build(Package, verbose = verbose, quiet = FALSE, VersionOnRepos = VersionOnRepos))
-          fn <- dir(pattern = paste0("^", Package, "_.+tar.gz"))
-          normPath(fn)
+          downloadAndBuildToLocalFile(Account, Repo, Branch, Package, GitSubFolder, verbose, VersionOnRepos)
+            # gitRepo <- paste0(Account, "/", Repo, "@", Branch)
+            # names(gitRepo) <- Package
+            # out <- downloadRepo(gitRepo, subFolder = GitSubFolder,
+            #                     overwrite = TRUE, destDir = ".", verbose = verbose)
+            # out1 <- try(build(Package, verbose = verbose, quiet = FALSE, VersionOnRepos = VersionOnRepos))
+            # fn <- dir(pattern = paste0("^", Package, "_.+tar.gz"))
+            # normPath(fn)
         }, by = "Package"] # seq(NROW(pkgGHtoDL))]
+
+        empty <- !nzchar(pkgGHtoDL[!SHAonGH %in% FALSE]$localFile)
+        if (any(empty))
+            pkgGHtoDL[which(!SHAonGH %in% FALSE)[empty %in% TRUE], localFile := "NeedRebuild"]
         # A bit of cleaning; this will get rid of the source files; we have the tar.gz after `build`
         pkgGHtoDL[, installFrom := "GitHub"]
         pkgGHtoDL <- renameLocalGitPkgDT(pkgGHtoDL)
@@ -1101,8 +1138,6 @@ dealWithSnapshotViolations <- function(pkgSnapshotObj, verbose = getOption("Requ
                                        repos = getOption("repos"), type = getOption("pkgType")) {
   dd <- pkgSnapshotObj
   ff <- packageFullNameFromSnapshot(dd)
-  # ff <- ifelse(!is.na(dd$GithubRepo) & nzchar(dd$GithubRepo),
-  #              paste0(dd$GithubUsername, "/", dd$Package, "@", dd$GithubSHA1), paste0(dd$Package, " (==", dd$Version, ")"))
   gg <- pkgDep(ff, recursive = TRUE, purge = purge)
   hh <- sort(unique(gsub("(\\(.*)( )+(.*\\))$", "\\1\\3", gsub("\n", "", unname(unlist(gg))))))
   pkgDT <- toPkgDT(hh, deepCopy = TRUE)
@@ -1315,9 +1350,17 @@ availablePackagesOverride <- function(toInstall, repos, purge, type = getOption(
   }
   ap <- available.packagesCached(repos = repos, purge = purge, returnDataTable = FALSE, type = type)
   pkgsNotInAP <- toInstall$Package[!toInstall$Package %in% ap[, "Package"]]
+  NumPkgsNotInAP <- length(pkgsNotInAP)
+
+  if (NumPkgsNotInAP) { # basically no version is there
+
+    # Have to make the ap object be the same length as the number of pkgsNotInAP
+    if (NROW(ap) < NumPkgsNotInAP) { # no nough rows; must add
+      ap3 <- rbind(ap, matrix(nrow = NumPkgsNotInAP, rep(rep(NA, NCOL(ap)), NumPkgsNotInAP)))
+    } else { #  too many rows, keep first NumPkgsNotInAP
+      ap3 <- ap[seq(NumPkgsNotInAP), , drop = FALSE]
+    }
 
-  if (length(pkgsNotInAP)) { # basically no version is there
-    ap3 <- ap[seq(length(pkgsNotInAP)), , drop = FALSE]
     ap3[, "Package"] <- pkgsNotInAP
     rownames(ap3) <- ap3[, "Package"]
     ap3[, "Version"] <- toInstall[Package %in% pkgsNotInAP]$VersionOnRepos
@@ -2136,3 +2179,41 @@ rmPackageFirst <- function(toInstall, verbose) {
   }
   toInstall
 }
+
+downloadAndBuildToLocalFile <- function(Account, Repo, Branch, Package, GitSubFolder, verbose, VersionOnRepos) {
+  gitRepo <- paste0(Account, "/", Repo, "@", Branch)
+  names(gitRepo) <- Package
+  out <- downloadRepo(gitRepo, subFolder = GitSubFolder,
+                      overwrite = TRUE, destDir = ".", verbose = verbose)
+  out1 <- try(build(Package, verbose = verbose, quiet = FALSE, VersionOnRepos = VersionOnRepos))
+  fn <- dir(pattern = paste0("^", Package, "_.+tar.gz"))
+  normPath(fn)
+}
+
+
+needRebuildAndInstall <- function(needRebuild, pkgInstall, libPaths, verbose, install.packagesArgs,
+                                  repos, purge, startTime, type,
+                                  pkgInstallTmp) {
+  if (any(needRebuild)) {
+    message("Trying to rebuild and install GitHub build fails... ")
+    pkgInstall[, needRebuild := needRebuild]
+    pkgInstallList <- split(pkgInstall, by = "needRebuild")
+    names(pkgInstallList) <- c("No", "GitHub")
+    pkgInstallList <- downloadGitHub(pkgInstallList, libPaths, verbose, install.packagesArgs)
+    maxGroup <- 1
+    numPackages <- NROW(pkgInstallList[["GitHub"]])
+    pkgInstallList[["GitHub"]][, installOrder := seq(.N)] # renumber the installOrder
+    pkgInstallList <- Map(
+      toInstall = pkgInstallList["GitHub"],
+      MoreArgs = list(
+        repos = repos, purge = purge,
+        install.packagesArgs = install.packagesArgs, numPackages = numPackages,
+        numGroups = maxGroup, startTime = startTime, verbose = verbose, type = type
+      ),
+      installAll
+    )
+    pkgInstall <- rbindlist(list(pkgInstallTmp[!Package %in% pkgInstallList[["GitHub"]]$Package],
+                                 pkgInstallList[["GitHub"]]), use.names = TRUE, fill = TRUE)
+  }
+  pkgInstall
+}
