@@ -181,8 +181,9 @@ if (identical(tolower(Sys.getenv("CI")), "true") || # travis
 
 # Code coverage
 if (isDev) { # i.e., GA, R CMD check etc.
-  pkg <- c("rforge/mumin/pkg", "Require")
+  pkg <- c("r-forge/mumin/pkg", "Require")
   names(pkg) <- c("MuMIn", "")
+  aaaa <<- 1
   out <- Require(pkg, install = FALSE, require = FALSE)
   testit::assert({
     isFALSE(all(out))
@@ -194,7 +195,7 @@ if (isDev) { # i.e., GA, R CMD check etc.
   ip <- data.table::as.data.table(installed.packages())
   testit::assert(NROW(ip[Package == reallyOldPkg]) == 1)
 
-  out <- getGitHubDESCRIPTION(data.table::data.table(packageFullName = "rforge/mumin/pkg"))
+  out <- getGitHubDESCRIPTION(data.table::data.table(packageFullName = "r-forge/mumin/pkg"))
   testit::assert({
     data.table::is.data.table(out)
   })
